@@ -453,7 +453,12 @@ class TestResumableUpload(object):
             assert headers == expected_headers
 
     def test__prepare_initiate_request_with_headers(self):
-        headers = {"caviar": "beluga", "top": "quark"}
+        # content-type header should be overwritten, the rest should stay
+        headers = {
+            "caviar": "beluga",
+            "top": "quark",
+            "content-type": "application/xhtml",
+        }
         data, new_headers = self._prepare_initiate_request_helper(
             upload_headers=headers
         )
